/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import javax.persistence.Basic;
import javax.persistence.Column;

import org.loom.annotation.validation.NestedAnnotations;
import org.loom.mapping.Event;
import org.loom.validator.AbstractRequiredValidator;
import org.loom.validator.RequiredValidatorFactory;


/**
 * Processes JPA annotations.
 * This processor will look inside any class that has been annotated with {@link NestedAnnotations}
 * and add validators corresponding to the metadata that is used to generate the database.
 * {@link Basic} and {@link Column} are supported.
 * @author icoloma
 *
 */
public class BasicAnnotationProcessor extends AbstractPropertyAnnotationProcessor<Basic, Basic> {

	public BasicAnnotationProcessor() {
		super(Basic.class, null);
	}

	@Override
	protected void process(Event event, Basic basic, String propertyPath) {
		
		// required validator
		Class<?> propertyClass = event.getPropertyClass(propertyPath);
		if (!basic.optional()) {
			AbstractRequiredValidator<?> validator = RequiredValidatorFactory.createValidator(propertyClass);
			validator.setPropertyPath(propertyPath);
			event.addValidator(validator);
		}

	}

}
