/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import java.lang.reflect.Method;

import javax.annotation.security.DenyAll;
import javax.annotation.security.PermitAll;
import javax.annotation.security.RolesAllowed;

import org.loom.action.Action;
import org.loom.mapping.Event;

/**
 * Processes JSR250 Common Annotations.
 * Right now {@link RolesAllowed}, {@link PermitAll} and {@link DenyAll} are processed
 * 
 * @author icoloma
 */
public class CommonAnnotationsProcessor extends AbstractSecurityAnnotationProcessor {

	@Override
	public void process(Event event) {
		boolean processed = false;
		
		// process method annotations
		Method method = event.getJavaMethod();
		PermitAll permitAll = method.getAnnotation(PermitAll.class);
		if (permitAll != null) {
			processed = true;
		} 
		
		RolesAllowed rolesAllowed = method.getAnnotation(RolesAllowed.class);
		if (rolesAllowed != null) {
			setEventRoles(event, rolesAllowed.value());
			processed = true;
		} 
		
		DenyAll denyAll = method.getAnnotation(DenyAll.class);
		if (denyAll != null) {
			setEventRoles(event, new String[] {});
			processed = true;
		}
		
		// process class annotations
		if (!processed) {
			Class<? extends Action> actionClass = event.getActionMapping().getActionClass();
			RolesAllowed classRolesAllowed = actionClass.getAnnotation(RolesAllowed.class);
			if (classRolesAllowed != null) {
				setEventRoles(event, classRolesAllowed.value());
			}
			DenyAll classDenyAll = actionClass.getAnnotation(DenyAll.class);
			if (classDenyAll != null) {
				setEventRoles(event, new String[] {});
			}
			
		}
		
	}
	
}
