/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import org.loom.annotation.RetrieveEntities;
import org.loom.annotation.RetrieveEntity;
import org.loom.exception.ConfigException;
import org.loom.interceptor.RetrieveEntityInterceptor;
import org.loom.mapping.Event;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;


/**
 * Processes {@link RetrieveEntity} annotations
 * @author icoloma
 *
 */
@Component
public class RetrieveEntityAnnotationProcessor extends AbstractPropertyAnnotationProcessor<RetrieveEntity, RetrieveEntities> implements ApplicationContextAware {

	private ApplicationContext applicationContext;
	
	/** the name of the interceptor in the application context */
	private String interceptorBeanName;
	
	public RetrieveEntityAnnotationProcessor() {
		super(RetrieveEntity.class, RetrieveEntities.class);
	}

	@Override
	protected void process(Event event, RetrieveEntity annotation, String propertyPath) {
		if (interceptorBeanName == null) {
			throw new ConfigException("Cannot process @RetrieveEntity at " + event.getPrintName() + ", no interceptor " + RetrieveEntityInterceptor.class.getName() + " has been configured");
		}
		RetrieveEntityInterceptor interceptor = (RetrieveEntityInterceptor) applicationContext.getBean(interceptorBeanName);
		interceptor.setReadOnly(annotation.readOnly());
		if (annotation.idPropertyName().length() > 0) {
			interceptor.setIdPropertyName(annotation.idPropertyName());
		}
		interceptor.setPropertyPath(propertyPath);
		interceptor.setPropertyClass(event.getPropertyClass(propertyPath));
		event.addInterceptor(interceptor);
	}

	public void setApplicationContext(ApplicationContext applicationContext) {
		this.applicationContext = applicationContext;
		String[] names = applicationContext.getBeanNamesForType(RetrieveEntityInterceptor.class);
		if (names.length > 0) {
			interceptorBeanName = names[0];
		}
	}

	public void setInterceptorBeanName(String interceptorBeanName) {
		this.interceptorBeanName = interceptorBeanName;
	}

}
