/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import org.loom.annotation.SingleUseToken;
import org.loom.exception.ConfigException;
import org.loom.interceptor.RetrieveEntityInterceptor;
import org.loom.interceptor.SingleUseTokenInterceptor;
import org.loom.mapping.Event;
import org.loom.servlet.HttpMethod;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Component;

/**
 * Process {@link SingleUseToken} annotations
 * @author icoloma
 */
@Component
public class SingleUseTokenAnnotationProcessor extends AbstractAnnotationProcessor {

	@Autowired
	private ApplicationContext applicationContext;

	private String interceptorBeanName;
	
	@Override
	public void process(Event event) {
		SingleUseToken annotation = event.getJavaMethod().getAnnotation(SingleUseToken.class);
		if (annotation != null) {
			if (event.supports(HttpMethod.GET)) { // GET events are idempotent, so this is not a valid situation
				throw new ConfigException("Cannot use @SingleUseToken with event " + event.getPrintName() + ": single use tokens cannot be used with GET events");
			}
			SingleUseTokenInterceptor interceptor = interceptorBeanName == null? new SingleUseTokenInterceptor() : (SingleUseTokenInterceptor) applicationContext.getBean(interceptorBeanName);
			event.addInterceptor(interceptor);
		}
	}
	
	public void setApplicationContext(ApplicationContext applicationContext) {
		this.applicationContext = applicationContext;
		String[] names = applicationContext.getBeanNamesForType(RetrieveEntityInterceptor.class);
		if (names.length > 0) {
			interceptorBeanName = names[0];
		}
	}

}
