/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.validation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.loom.i18n.Message;

/**
 * String validation rules
 * @author Ignacio Coloma
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.FIELD, ElementType.METHOD, ElementType.PARAMETER})
@Documented
public @interface StringValidation {

	/** e-mail mask */
	public static String EMAIL_MASK = "^([a-zA-Z0-9._%+-]+)@([a-zA-Z0-9.-]+\\.[a-zA-Z]{2,4}$)";

	/** 
	 * web image mask 
	 * @deprecated use {@link ImageValidation} instead
	 */
	public static String WEB_IMAGE_MASK = "(.*?)\\.(jpg|jpeg|png|gif)$";

	/** phone mask */
	public static final String PHONE_MASK = "^\\+?[A-Za-z0-9 ()\\-]{9,}$";
	
    /** if provided, applies to the property path instead of the annotated property */
    String propertyPath() default "";
    
    /** the list of events in which this validation takes place, empty for all. Accepts wildcards. */
    String[] on() default {};
    
    /** the list of events in which this validation does NOT place, empty for none. Accepts wildcards. */
    String[] except() default {};
    
    /** the key of the message that will be displayed if the validator does not pass, leave empty for default */
    String message() default "";

    /** true if the any error message should be bound to this field, false to use unbound {@link Message}s */
    boolean bindMessages() default true;
  
    /** minimum length required, -1 if none */
    int minLength() default -1;
    
    /** maximum length allowed, -1 if none */
    int maxLength() default -1;
    
    /** the expected pattern */
    String mask() default "";

    /** true if the mask is case insensitive, defaults false */
	boolean maskCaseInsensitive() default false;
    	
}
