/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.binding;

import java.lang.reflect.Array;

/** 
 * A Node representing a List
 * @author Ignacio Coloma
 */
public class ArrayNode extends AbstractCollectionNode {

	@Override
	protected Object get(Object list, int index) {
		return Array.get(list, index);
	}

	@Override
	protected int getSize(Object list) {
		return Array.getLength(list);
	}

	@Override
	protected void set(Object list, int index, Object item) {
		Array.set(list, index, item);
	}
	
	@Override
	protected Object ensureCapacity(Object container, Object list, int newSize) {
		int originalSize = getSize(list);
		if (originalSize >= newSize) {
			return list;
		}
		Object newArray = Array.newInstance(list.getClass().getComponentType(), newSize);
		System.arraycopy(list, 0, newArray, 0, originalSize);
		getPropertyWrapper().set(container, newArray);
		return newArray;
	}

}
