/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.converter;

import org.loom.i18n.Messages;
import org.loom.i18n.MessagesRepository;
import org.loom.log.Log;
import org.loom.servlet.names.CssClassNames;

/**
 * number format that is not locale-dependant (integer,  long, etc)
 * @author icoloma
 */
public abstract class AbstractSimpleNumberConverter extends AbstractStringConverter implements LocaleUnawareConverter {

	private static Log log = Log .getLog(AbstractSimpleNumberConverter.class);
	
	protected AbstractSimpleNumberConverter(Class<?> convertedClass) {
		super(convertedClass);
		setCssClass(CssClassNames.NUMBER);
	}

	@Override
	public Object getAsObjectImpl(String name, String value, Messages messages, MessagesRepository repository) {
		try {
			return getAsObject(value);
		} catch (NumberFormatException e) {
			log.debug("Value for ", value, " is not valid");
			addErrorMessage(messages, name, value, "loom.conversion.numberFailed");
			return null;
		}
	}
	
	public abstract Object getAsObject(String text);
	
}
