/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.converter;

import org.loom.i18n.Messages;
import org.loom.i18n.MessagesRepository;
import org.loom.validator.FormInputDecorator;

/**
 * Makes the conversion between text and the java object that will be populated.
 * Converters must be stateless and thread-safe. That means that they should 
 * not have private non-static attributes, unless you know what you are doing. 
 * @author Ignacio Coloma
 */
public interface Converter extends FormInputDecorator {
	
	/**
	 * Return the object value for the given text
	 * @param paramValue the value that is being parsed
	 * @return the parsed value (can be null), maybe ading new values to the errors array 
	 */
	public Object getAsObject(String paramName, String paramValue, Messages messages, MessagesRepository repository);

	/**
	 * Return the text value for the given object
	 * @param value the java object to convert to text 
	 * @param repository the MessagesRepository object
	 * @return the parsed value (can be null) 
	 */
	public String getAsText(Object value, MessagesRepository repository);
	
	/**
	 * @return the Class of the converted values.
	 */
	public Class<?> getConvertedClass();
	
}