/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.exception;

import org.loom.resolution.Resolution;
import org.loom.servlet.Phase;

/**
 * Thrown when the workflow execution must be interrupted.
 * This is not really an exception, and includes the Resolution that
 * should be returned to the browser.
 *  
 * @author Ignacio Coloma
 */
public class WorkflowInterruption extends Exception {

	/** the Resolution that must be returned */
	private Resolution resolution;
	
	/** the workflow phase were this interruption happened */
	private Phase phase;

	public WorkflowInterruption(Phase phase, Resolution resolution) {
		this.resolution = resolution;
		this.phase = phase;
	}

	public Resolution getResolution() {
		return resolution;
	}

	public Phase getPhase() {
		return phase;
	}

}
