/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.filter;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletRequestFactory;
import org.loom.servlet.LoomServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.context.WebApplicationContext;
import org.springframework.web.context.support.WebApplicationContextUtils;


/**
 * Filter superclass that provides {@link LoomServletRequest} and {@link LoomServletResponse} wrappers.
 * @author icoloma
 */
public abstract class AbstractLoomFilter implements Filter {
	
	/** in case this filter is injected instead of configured using web.xml */
	@Autowired
	private LoomServletRequestFactory loomServletRequestFactory;

	public final void doFilter(ServletRequest req, ServletResponse resp, FilterChain chain) throws IOException, ServletException {
		LoomServletRequest request = loomServletRequestFactory.getOrCreateInstance(req);
		LoomServletResponse response = loomServletRequestFactory.getResponseInstance(request, resp);
		doFilter(request, response, chain);
	}
	
	protected abstract void doFilter(LoomServletRequest request, LoomServletResponse response, FilterChain chain) throws IOException, ServletException;

	public void destroy() {
	}

	public void init(FilterConfig filterConfig) throws ServletException {
		if (loomServletRequestFactory == null) {
			WebApplicationContext appContext = WebApplicationContextUtils.getWebApplicationContext(filterConfig.getServletContext());
			if (appContext == null) {
				throw new IllegalArgumentException("An application context has not yet been initialized. Please check that your ContextLoaderListener is defined before any filter in web.xml");
			}
			loomServletRequestFactory = (LoomServletRequestFactory) appContext.getBean("loomServletRequestFactory");
			if (loomServletRequestFactory == null) {
				throw new IllegalArgumentException("No loomServletRequestFactory has been defined");
			}
		}
	}

	public void setLoomServletRequestFactory(LoomServletRequestFactory requestFactory) {
		this.loomServletRequestFactory = requestFactory;
	}

}
