/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.filter;

import java.io.IOException;
import java.util.Set;
import java.util.TreeSet;

import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;

import org.apache.commons.lang.StringUtils;
import org.loom.log.Log;
import org.loom.servlet.CacheControl;
import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletResponse;
import org.loom.util.UrlMatcher;

/**
 * Sets the browser cache for the filtered resources.
 * @deprecated You will get better performance just by putting your cached resources together in a certain folder and caching the entire folder. 
 * 
 * @author icoloma
 */
public class StaticResourcesFilter extends AbstractLoomFilter {

	/** the list of configured patterns */
	private UrlMatcher matcher = new UrlMatcher();

	/** the list of methods that are not cached */
	private Set<String> skipMethods;
	
	/** the cache data */
	private CacheControl cacheControl;
	
	private static Log log = Log.getLog(StaticResourcesFilter.class);
	
	/**
	 * Expected init argument: 
	 * patterns: list of regex for  matching patterns, separated by commas, spaces, tabs or newlines
	 */
	@Override
	public void init(FilterConfig filterConfig) throws ServletException {
		super.init(filterConfig);
		log.warn("StaticResourcesFilter has been deprecated!");
		
		cacheControl = new CacheControl().forever();
		
		String patterns = filterConfig.getInitParameter("includes");
		if (patterns !=  null) {
			this.matcher.setInclude(patterns != null? StringUtils.split(patterns, ",\n\t ") : new String[] { "-[\\d.]+.*/", "-[\\d.]+\\.\\w+$" });
		} 
		patterns = filterConfig.getInitParameter("excludes");
		if (patterns !=  null) {
			this.matcher.setExclude(StringUtils.split(patterns, ",\n\t "));
		} 
		
		skipMethods = new TreeSet<String>();
		skipMethods.add("PUT");
		skipMethods.add("POST");
		skipMethods.add("DELETE");
	}

	@Override
	public void doFilter(LoomServletRequest request, LoomServletResponse response, FilterChain chain)
			throws IOException, ServletException {
		if (matcher.matches(request) && !skipMethods.contains(request.getMethod())) {
			log.debug("Request '", request.getServletPath(), "' is being marked as CACHE FOREVER");
			cacheControl.writeHeaders(response);
		}
		chain.doFilter(request, response);
	}

	@Override
	public void destroy() {
	}
	
}
