/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.i18n;

import java.util.Set;
import java.util.TreeSet;

import org.loom.log.Log;
import org.loom.util.PropertyUtils;

/**
 * This message handler logs a  list of missing keys, to make them easier to add later.
 * The recommended behavior is to configure your log system to redirect this class output
 * to a separate file, such as ${java.io.temp}/missing.properties.
 * Each missing key will just be written once
 * @author icoloma
 */
public class DefaultMissingMessageHandler implements MissingMessageHandler {

	/** the properties already logged */
	private Set<String> missingKeys = new TreeSet<String>();
	
	private static Log log = Log .getLog(DefaultMissingMessageHandler.class);
	
	public String handleMissingParameter(String missingParamName) {
		logMissingKey(missingParamName);
		for (String s = PropertyUtils.removeRootNode(missingParamName); s != null; s = PropertyUtils.removeRootNode(s)) {
			logMissingKey("  " + s);
		}
		return "[missing: " + missingParamName + "]";
	}
	
	public String handleMissingKey(String missingKey) {
		logMissingKey(missingKey);
		return "[missing: " + missingKey + "]";
	}

	/**
	 * Adds a missing key to the missing key respository 
	 * @param missingKey
	 */
	protected void logMissingKey(String missingKey) {
		if (!missingKeys.contains(missingKey)) {
			log.warn("Missing: ", missingKey);
			missingKeys.add(missingKey);
		}
	}
	
	public String handleMessageError(String messageKey, Throwable error) {
		throw new RuntimeException("Error happened while trying to translate " + messageKey, error);
	}
	
}
