package org.loom.i18n;

import java.text.DecimalFormat;

import org.loom.util.FileSizeUnit;

/**
 * A class capable of formatting a file size in a human readable format
 * @author icoloma
 *
 */
public class FileSizeFormatter {

	/** number of decimals to display after dividing, default 2 */
	private int precision = 2;
	
	/** the current MessagesRepository instance */
	private MessagesRepository messagesRepository;
	
	/**
	 * @return the formatted value
	 */
	public String format(Number value) {
		DecimalFormat format = new DecimalFormat("#,###.##");
		format.setMaximumFractionDigits(precision);
		if (messagesRepository != null) {
			format.setDecimalFormatSymbols(messagesRepository.createDecimalFormatSymbols());
		}
		
		FileSizeUnit[] units = FileSizeUnit.values();
		long l = value.longValue();
		String result = null;
		for (int i = units.length - 1; i >= 0; i--) { // notice the inverse order
			FileSizeUnit unit = units[i];
			if (l >= unit.getSize()) {
				result = format.format(((double) l) / unit.getSize()) + " " + unit.name();
				break;
			}
		}
		if (result == null) {
			result = l == 1? "1 byte" : format.format(l) + " bytes";
		}
		return result;
	}

	public void setPrecision(int precision) {
		this.precision = precision;
	}

	public void setMessagesRepository(MessagesRepository messagesRepository) {
		this.messagesRepository = messagesRepository;
	}
	
}
