package org.loom.i18n;

import java.util.Collection;
import java.util.Collections;
import java.util.Map;
import java.util.Set;

/**
 * Adapter to access MessagesRepository as a Map interface
 * @author icoloma
 *
 */
public class MessagesRepositoryToMapAdapter implements Map<String, String> {

	/** the unmodifiable map of contents */
	private Map<String, String> contents;
	
	/** the underlying MessagesRepository class */
	private MessagesRepository messagesRepository;

	public MessagesRepositoryToMapAdapter(MessagesRepository messagesRepository) {
		this.messagesRepository = messagesRepository;
		this.contents = Collections.unmodifiableMap(messagesRepository.getContents());
	}

	public MessagesRepository getMessagesRepository() {
		return messagesRepository;
	}
	
	// --------------+------------- Map methods start here -----------+---------- 

	public void clear() {
		contents.clear();
	}

	public boolean containsKey(Object key) {
		return contents.containsKey(key);
	}

	public boolean containsValue(Object value) {
		return contents.containsValue(value);
	}

	public Set<java.util.Map.Entry<String, String>> entrySet() {
		return contents.entrySet();
	}

	@Override
	public boolean equals(Object o) {
		return contents.equals(o);
	}

	public String get(Object key) {
		return contents.get(key);
	}

	@Override
	public int hashCode() {
		return contents.hashCode();
	}

	public boolean isEmpty() {
		return contents.isEmpty();
	}

	public Set<String> keySet() {
		return contents.keySet();
	}

	public String put(String key, String value) {
		return contents.put(key, value);
	}

	public void putAll(Map<? extends String, ? extends String> t) {
		contents.putAll(t);
	}

	public String remove(Object key) {
		return contents.remove(key);
	}

	public int size() {
		return contents.size();
	}

	public Collection<String> values() {
		return contents.values();
	}
	
	// --------------+------------- Map methods end here -----------+---------- 

}
