/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.mapping;

import java.util.ArrayList;
import java.util.List;

import org.loom.util.PropertyUtils;


/**
 * The already visited path.
 * While searching for validations, this class holds the navigated property path
 * @author icoloma
 */
public class VisitedPath {
	
	/** the visited path, null for none */
	private String propertyPath;
	
	public VisitedPath(String propertyPath) {
		setPropertyPath(propertyPath);
	}
	
	public VisitedPath(VisitedPath parentPath, String propertyName) {
		this.propertyPath = PropertyUtils.concatPropertyPath(parentPath.getPropertyPath(), propertyName);
		if (this.propertyPath.length() > 1024) {
			// the real purpose of this is to avoid infinite loops
			throw new IllegalArgumentException("Property path too long: " + propertyPath);
		}
	}

	/**
	 * Concatenates two arrays, ignoring duplicates
	 */
	public static String[] concatArrays(String[] array1, String[] array2) {
		List<String> result = new ArrayList<String>(array1.length + array2.length);
		for (String s : array1) {
			result.add(s);
		}
		for (String s : array2) {
			if (!result.contains(s)) {
				result.add(s);
			}
		}
        return result.toArray(new String[result.size()]);
	}

	public String getPropertyPath() {
		return propertyPath;
	}

	public void setPropertyPath(String propertyPath) {
		this.propertyPath = propertyPath;
	}

}