/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.persistence;

import javax.persistence.Entity;

import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.context.annotation.ClassPathScanningCandidateComponentProvider;
import org.springframework.core.type.filter.AnnotationTypeFilter;
import org.springframework.orm.jpa.persistenceunit.MutablePersistenceUnitInfo;

/**
 * Adds persistent classes found in the specified packages to your JPA config.
 * @author icoloma
 */
public class PackagesPersistenceUnitPostProcessor 
	implements org.springframework.orm.jpa.persistenceunit.PersistenceUnitPostProcessor, InitializingBean {

	/** used to scan for persistent classes */
	private ClassPathScanningCandidateComponentProvider provider;

	/** packages where to look for persistent classes */
	private String[] packages; // = new String[] { "org.loom.addons.persistence" };

	/**
	 * Search for persistent classes under the configured folders and register them 
	 * in the persistence unit.
	 */
	public void postProcessPersistenceUnitInfo(MutablePersistenceUnitInfo unit) {
		for (String pakage : packages) {
			for (BeanDefinition bean : provider.findCandidateComponents(pakage)) {
				unit.addManagedClassName(bean.getBeanClassName());
			}
		}
	}

	public void afterPropertiesSet() {
		if (provider == null) {
			provider = new ClassPathScanningCandidateComponentProvider(false);
			provider.addIncludeFilter(new AnnotationTypeFilter(Entity.class, false));
		}
		if (packages == null) {
			throw new IllegalArgumentException("Packages is required");
		}
	}

	public void setProvider(ClassPathScanningCandidateComponentProvider provider) {
		this.provider = provider;
	}

	public void setPackages(String[] packages) {
		this.packages = packages;
	}

}
