/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.persistence.file;

import java.io.InputStream;
import java.sql.Blob;
import java.sql.SQLException;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Lob;
import javax.persistence.Table;

/**
 * A PersistentFile implementation that persists file contents as a BLOB
 * @author icoloma
 */
@Entity
@Table(name="file_contents")
public class BlobPersistentFileContents extends DatabaseFileContents {

	/** file contents */
	@Lob
	@Column(name="contents")
	private Blob contentsAsBlob;

	public Blob getContentsAsBlob() {
		return contentsAsBlob;
	}
	
	public InputStream getContentsAsStream() {
		try {
			Blob b = getContentsAsBlob();
			return b == null? null : b.getBinaryStream();
		} catch (SQLException e) {
			throw new RuntimeException(e);
		}
	}

	public void setContentsAsBlob(Blob contentsAsBlob) {
		this.contentsAsBlob = contentsAsBlob;
	}
	
	public Long getFileSize() {
		try {
			return contentsAsBlob.length();
		} catch (SQLException e) {
			throw new RuntimeException(e);
		}
	}

}
