/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.persistence.file;

import org.loom.exception.EntityNotFoundException;
import org.loom.servlet.params.FileParameter;


/**
 * Handle persistent files
 * @author icoloma
 *
 */
public interface FileManager {

	/**
	 * Stores a file in the database and return the persistent instance
	 * @param fileParameter the uploaded parameter file
	 * @return the persisted instance
	 */
	public PersistentFile merge(FileParameter fileParameter);
	
	/**
	 * Stores a file in the database and return the persistent instance
	 * @param file the modified file to store
	 * @return the persisted instance
	 */
	public PersistentFile merge(PersistentFile file);
	
	/**
	 * @param id the persistent file id
	 * @return the persistent file entity
	 * @throws EntityNotFoundException if there is no persistent file with the provided id.
	 */
	public PersistentFile find(Integer id);

	/**
	 * Removes a persistent file from the database
	 * @param id the file id to remove
	 * @return the removed file entity
	 * @throws EntityNotFoundException if there is no persistent file with the provided id.
	 */
	public PersistentFile remove(Integer id);
	
}
