/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.resolution;

import static org.loom.util.FileUtils.copy;

import java.io.IOException;
import java.io.InputStream;
import java.util.Collection;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

import javax.servlet.ServletException;

import org.apache.commons.io.IOUtils;
import org.loom.persistence.file.PersistentFile;
import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletResponse;
import org.loom.util.MimeUtils;


/**
 * Delivers a zip file to the browser
 * 
 * @author ggarcia
 */
public class ZipFileResolution extends AbstractFileResolution {

	/** the list of files to zip */
	private Collection<PersistentFile> files;
	
	public ZipFileResolution(String filename, Collection<PersistentFile> files) {
		if (filename == null) {
			throw new IllegalArgumentException("name cannot be null");
		}
		if (files == null) {
			throw new IllegalArgumentException("files cannot be null");
		}
		this.setFilename(filename);
		this.setContentType(MimeUtils.guessMimeType(filename));
		this.files = files;
	}
	
	@Override
	public void resolve(LoomServletRequest request, LoomServletResponse response) throws IOException, ServletException {
		writeHeaders(request, response);

		ZipOutputStream zipOutput = new ZipOutputStream(response.getOutputStream());
		try {
			for (PersistentFile persistentFile : files) {
				zipOutput.putNextEntry(new ZipEntry(persistentFile.getFilename()));
				InputStream input = null;
				try {
					input = persistentFile.getContentsAsStream();
					copy(input, zipOutput);
				} finally {
					IOUtils.closeQuietly(input);
					zipOutput.closeEntry();
				}
			}
		} finally {
			zipOutput.close();
		}
	}
}
