package org.loom.resources;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.tags.core.AbstractWebResourceTag;


/**
 * A list of resources (javascript or css files) to be merged before delivering to the browser.
 * @author icoloma
 *
 */
public interface WebResourceBundle {

	/** resource name when working in production mode */
	public static final String PROD_RESOURCE_NAME = "";

	/**
	 * Write the tag or tags for this bundle
	 */
	void render(AbstractWebResourceTag tag) throws JspException, IOException;

	/**
	 * Invoke to reset the internal state of this bundle so its contents are recalculated on the next browser request
	 */
	public void reload();
	
	/**
	 * Returns the compiled web resource (a JS/CSS file). If name is null (production mode), returns the first  
	 * resource in this bundle which should contain the full contents of the bundle in a single, minified file.
	 */
	public CompiledWebResource getCompiledWebResource(String name);

	/**
	 * Return the type of this bundle (js/css)
	 */
	public WebResourceType getType();

	/**
	 * Return an external resource referenced from one of the CSS stylesheets (url() attribute) contained in this bundle
	 * @param name the name of the resource
	 * @return the resource (image file)
	 */
	public CssResource getCssResource(String name);

	public String getName();

	public void addWebResourceBundleEventListener(WebResourceBundleEventListener listener);
}
