package org.loom.resources;

import java.util.List;

import javax.annotation.PostConstruct;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.Resource;
import org.springframework.core.io.ResourceLoader;

import com.google.common.collect.ImmutableList;
import com.google.common.collect.Sets;


public class WebResourceBundleFactoryImpl implements WebResourceBundleFactory {

	/** the compiler to use for js files */
	private WebResourceCompiler jsCompiler;
	
	/** the compiler to use for CSS files */
	private WebResourceCompiler cssCompiler;
	
	@Autowired
	private ResourceLoader resourceLoader;
	
	@PostConstruct
	public void initDefaultCompilers() {
		if (jsCompiler == null) {
			jsCompiler = initDefaultCompiler(WebResourceType.JS);
		}
		if (cssCompiler == null) {
			cssCompiler = initDefaultCompiler(WebResourceType.CSS);
		}
	}
	
	protected WebResourceCompiler initDefaultCompiler(WebResourceType type) {
		InMemoryWebResourceCompiler compiler = new InMemoryWebResourceCompiler();
		compiler.setResourceLoader(resourceLoader);
		compiler.setType(type);
		return compiler;
	}
	
	@Override
	public WebResourceBundle create(String location) {
		Resource resource = resourceLoader.getResource(location);
		if (!resource.exists()) {
			throw new IllegalArgumentException(location + " is not configured as a WebResourceBundle and does not correspond to any existing file location");
		}
		return create(StringUtils.substringAfterLast(location, "/"), ImmutableList.of(resource));
	}
	
	@Override
	public WebResourceBundle create(String name, List<Resource> resources) {
		WebResourceBundleImpl bundle = new WebResourceBundleImpl();
		bundle.setResources(Sets.newLinkedHashSet(resources));
		bundle.setName(name);
		bundle.setCompiler(bundle.getType() == WebResourceType.CSS? cssCompiler : jsCompiler);
		return bundle;
	}
	
	@Override
	public void setDevelopment(boolean development) {
		jsCompiler.setDevelopment(development);
		cssCompiler.setDevelopment(development);
	}

	public void setJsCompiler(WebResourceCompiler jsCompiler) {
		this.jsCompiler = jsCompiler;
	}

	public void setCssCompiler(WebResourceCompiler cssCompiler) {
		this.cssCompiler = cssCompiler;
	}

	public void setResourceLoader(ResourceLoader resourceLoader) {
		this.resourceLoader = resourceLoader;
	}

}
