/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.security;

import java.util.Collection;

import org.springframework.security.access.AccessDeniedException;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;

/**
 * Adapts the spring security project (formerly known as acegi security)
 * @author icoloma
 */
public class SpringSecurityAdapter implements SecurityAdapter {

	/** 
	 * the prefix added to each role before asking spring-security 
	 * @deprecated this property does not constitute a good practice. Instead, use the same role
	 * name in the repository and the security annotations.
	 */
	private String rolePrefix= "";
	
	public boolean hasRole(String[] allowedRoles) {
		Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
		Collection<GrantedAuthority> authorities = authentication == null? null : authentication.getAuthorities();
		if (authorities != null) {
			for (String role : allowedRoles) {
				String springRoleName = rolePrefix + role;
				for (GrantedAuthority authority : authorities) {
					if (springRoleName.equals(authority.getAuthority())) {
						return true;
					}
				}
			}
		}
		return false;
	}
	
	/**
	 * This method will throw an instance of {@link AccessDeniedException}
	 */
	public void throwInsufficientPermissionsException(String message) {
		throw new AccessDeniedException(message);
	}

	public String getRolePrefix() {
		return rolePrefix;
	}

	public void setRolePrefix(String rolePrefix) {
		this.rolePrefix = rolePrefix;
	}

}
