package org.loom.servlet.names;

/**
 * Standards-compliant names for the typical MIME Content-Type headers.
 * For other MIME-types, see <a href="http://en.wikipedia.org/wiki/Internet_media_type">the internet media types at wikipedia</a>
 * 
 * @author icoloma
 *
 */
public class ContentTypeNames {

	/**
	 * <a href="http://www.ietf.org/rfc/rfc4329.txt">Javascript files</a> 
	 * Other commonly used MIME-types are:
	 * <ul>
	 * <li><code>application/ecmascript</code></li>
	 * <li><code>application/javascript</code></li>
	 * <li><code>application/x-ecmascript</code></li>
	 * <li><code>application/x-javascript</code></li>
	 * <li><code>text/ecmascript</code></li>
	 * <li><code>text/javascript</code></li>
	 * <li><code>text/x-ecmascript</code></li>
	 * <li><code>text/x-javascript</code></li>
	 * </ul>
	 */
	public static final String JAVASCRIPT = "application/javascript"; 
	
	/** 
	 * <a href="http://www.ietf.org/rfc/rfc4627.txt">JSON files</a>
	 * Other common-use type is text/json 
	 */
	public static final String JSON = "application/json"; 
	
	/**
	 * <a href="http://www.ietf.org/rfc/rfc3676.txt">Plain text</a>
	 */
	public static final String TEXT = "text/plain"; 
	
	/**
	 * <a href="http://www.ietf.org/rfc/rfc3676.txt">CSS</a>
	 */
	public static final String CSS = "text/css"; 
	
}
