package org.loom.spring;

import java.util.Map;

import org.loom.annotation.processor.AnnotationProcessor;
import org.loom.config.Config;
import org.loom.converter.AnnotationDrivenConverterFactory;
import org.loom.converter.Converter;
import org.loom.converter.ConverterRepository;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;

/**
 * Detect and add to the current config any {@link AnnotationProcessor} and {@link Converter}
 * configured using spring
 * @author icoloma
 *
 */
public class ConfigPostProcessor implements ApplicationContextAware, InitializingBean {

	@Autowired
	private ApplicationContext applicationContext;

	@Autowired
	private Config config;
	
	@SuppressWarnings("unchecked")
	public void afterPropertiesSet() throws Exception {
		for (AnnotationProcessor annotationProcessor: ((Map<String, AnnotationProcessor>)applicationContext.getBeansOfType(AnnotationProcessor.class)).values()) {
			addAnnotationProcessor(annotationProcessor);
		}
		for (Converter converter: ((Map<String, Converter>)applicationContext.getBeansOfType(Converter.class)).values()) {
			ConverterRepository.getInstance().setConverter(converter.getConvertedClass(), converter);
		}
		for (AnnotationDrivenConverterFactory factory: ((Map<String, AnnotationDrivenConverterFactory>)applicationContext.getBeansOfType(AnnotationDrivenConverterFactory.class)).values()) {
			ConverterRepository.getInstance().addConverterFactory(factory);
		}
	}
	
	private void addAnnotationProcessor(AnnotationProcessor annotationProcessor) {
		config.getActionMappingRepository().getActionMappingFactory().addAnnotationProcessor(annotationProcessor);
	}

	public void setApplicationContext(ApplicationContext applicationContext) {
		this.applicationContext = applicationContext;
	}

}
