/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.core;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.config.ConfigProperties;
import org.loom.tags.AbstractFormInputTag;
import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;


/**
 * <a href="http://www.w3.org/TR/html4/interact/forms.html#input-control-types">HTML input image tag</a>
 * @author icoloma
 *
 */
@Tag(
		dynamicAttributes=true,
		bodyContent=BodyContent.EMPTY
	)
public class InputImageTag extends AbstractFormInputTag {
	
	private static String DEFAULT_CSS = ConfigProperties.getInstance().getDefaultCss(InputImageTag.class, null);
	
	/** <a href="http://www.w3.org/TR/html4/interact/forms.html#adef-src">HTML attribute</a> */
	@Attribute(required=true)
	private String src;
	
	/** <a href="http://www.w3.org/TR/html4/struct/objects.html#adef-usemap">HTML attribute</a> */
	@Attribute
	private String usemap;

	public InputImageTag() {
		setCssClass(DEFAULT_CSS);
	}
	
	public void setSrc(String src) {
		this.src = src;
	}

	public void setUsemap(String usemap) {
		this.usemap = usemap;
	}

	@Override
	public void doTagImpl() throws JspException, IOException {
		out.print("<input type=\"image\"");
		out.printAttribute("src", src);
		out.printAttribute("usemap", usemap);
		printParentAttributes();
		out.print(" />");
	}

}
