/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.core;


import org.loom.i18n.MessagesRepository;

/**
 * An option in the {@link AbstractOptionsTag} Tag
 * @author icoloma
 */
public class Option {

	/** the empty value */
	public static Option NULL_OPTION = new Option(null, "", false);
	
	/** the value that will be assigned */
	private Object value;
	
	/** the associated label */
	private String label;
	
	/** true to translate the label before printing */
	private boolean translateLabel;

	/** (calculated) the value that will be output as label (can be translated or not) */
	private String processedLabel;
	
	public Option(Object value, String label, boolean translateLabel) {
		this.value = value;
		this.label = label == null? "" : label;
		this.translateLabel = translateLabel;
	}

	/**
	 * @return true if this option is equals to the provided value
	 */
	public boolean isSelected(Object currentValue) {
		if (value == null) {
			return currentValue == null;
		} else {
			return value.equals(currentValue);
		}
	}
	
	@Override
	public int hashCode() {
		return value == null? 0 : value.hashCode();
	}
	
	@Override
	public boolean equals(Object obj) {
		if (obj == null || !(obj instanceof Option)) {
			return false;
		}
		Option other = (Option) obj;
		if (value == null) {
			return other.getValue() == null && label.equals(other.label);
		}
		return value.equals(other.getValue()) && label.equals(other.label);
	}
	
	public String getLabel(MessagesRepository repository) {
		if (processedLabel == null) {
			processedLabel = translateLabel? repository.guessString(label) : label;
		}
		return processedLabel;
	}

	public Object getValue() {
		return value;
	}
	
	@Override
	public String toString() {
		return "Option { value = " + value + ", label = " + label + ", translate = " + translateLabel + " }";
	}

	public boolean isTranslateLabel() {
		return translateLabel;
	}

}
