/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.decorator;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.servlet.Scope;
import org.loom.tags.core.UrlTag;

/**
 * Render just the link of a UrlTag, skipping the "<a href=..." tag.
 * Useful to just print the link.
 * @author icoloma
 */
public class LinkOnlyDecorator extends AbstractLoomDecorator<UrlTag> {

	@Override
	public boolean beforeDoTag(UrlTag tag) throws IOException, JspException {
		tag.setVar("loom-dummy");
		return true;
	}

	@Override
	public void afterDoTag(UrlTag tag) throws IOException, JspException {
		String link = (String)tag.getScopedAttribute("loom-dummy", Scope.PAGE);
		tag.getWriter().print(link);
		tag.removeScopedAttribute("loom-dummy", Scope.PAGE);
	}

}
