package org.loom.tags.messages;

import org.loom.util.DateUtils;
import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;

/**
 * Format a lapse of time in seconds/minutes/hours/days.  
 * Equivalent to <a href="http://api.rubyonrails.org/classes/ActionView/Helpers/DateHelper.html#M001695">DateHelper.distance_of_time_in_words</a> in Ruby
 * and Date.toDuration().humanized() in format.js
 * @author icoloma
 *
 */
@Tag(
		bodyContent=BodyContent.SCRIPTLESS,
		example="&lt;l:formatDuration value=\"${myDurationInMillis}\"/>"
	)
public class FormatDurationTag extends AbstractFormatTag {
	
	/** interval to format, in milliseconds */
	@Attribute(required=true)
	private long value;

	/** the maximum number of units to use (years, months, days, etc). Default is 2 */
	@Attribute
	private int maxUnits = 2;
	
	@Override
	public String format() {
		return DateUtils.humanizedDuration(repository, value, maxUnits);
	}

	public void setValue(long value) {
		this.value = value;
	}

	public void setMaxUnits(int maxUnitsCount) {
		this.maxUnits = maxUnitsCount;
	}

}
