package org.loom.tags.messages;

import org.loom.i18n.FileSizeFormatter;
import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;

/**
 * Format a file size in bytes, KB, MB or TB as needed.
 * Equivalent to <a href="http://api.rubyonrails.org/classes/ActionView/Helpers/NumberHelper.html#M001688">NumberHelper.number_to_human_size</a> in Ruby
 * @author icoloma
 *
 */
@Tag(
		bodyContent=BodyContent.SCRIPTLESS,
		example="&lt;l:formatFileSize value=\"${123.5 * 1024}\"/>"
	)
public class FormatFileSizeTag extends AbstractFormatTag {
	
	/** value to format */
	@Attribute(required=true)
	private Number value;
	
	private FileSizeFormatter format = new FileSizeFormatter();
	
	@Override
	public String format() {
		format.setMessagesRepository(repository);
		return format.format(value);
	}
	
	public void setValue(Number value) {
		this.value = value;
	}

	@Attribute
	public void setPrecision(int precision) {
		this.format.setPrecision(precision);
	}

}
