package org.loom.tags.paged;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.paged.PagedListData;
import org.loom.tags.AbstractTag;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;

/**
 * Contains the &lt;tfoot> contents of the surrounding &lt;pagedTable>.
 * This tag will get rendered once, after the table contents have been processed.
 * 
 * @author icoloma
 *
 */
@Tag(
		dynamicAttributes=true, 
		bodyContent=BodyContent.SCRIPTLESS,
		example=
		"&lt;c:set var=\"total\" value=\"0\"/>\n" +
		"&lt;l:pagedTable>\n" +
		"  &lt;l:column property=\"id\" />\n" +
		"  &lt;l:column property=\"amount\" />\n" +
		"  &lt;c:set var=\"total\" value=\"${total + row.amount}\"/>\n" +
		"  &lt;l:footer/>\n" +
		"      &lt;tr>&lt;td>Total&lt;/td>&lt;${total}&lt;/td>&lt;/tr>\n" +
		"  &lt;/l:footer>\n" +
		"&lt;/l:pagedTable>"
	)
public class FooterTag extends AbstractTag {
	
	/** The surrounding table */
	private PagedTableTag table;

	@Override
	public void doTagImpl() throws JspException, IOException {
		if (table == null) {
			table = getAncestorWithClass(PagedTableTag.class);
		}
		
		PagedListData<?> data = table.getData();
		if (table.getRowIndex() == data.getData().size() - 1) {
			table.setFooter(doBufferedBody());
		} 
	}
	
}
