/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.tabs;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.i18n.MessagesRepository;
import org.loom.tags.WriterWrapper;
import org.loom.url.UrlBuilder;

/**
 * Render a tab 
 * @author icoloma
 */
public class DefaultTabDecorator implements TabDecorator {

	public boolean beforeDoTag(TabTag tag) throws IOException, JspException {
		WriterWrapper<?> out = tag.getWriter();
		out.print("<div");
		out.printAttribute("id", tag.getId());
		out.printAttribute("class", "tab");
		out.print(">\n");
		return true;
	}
	
	public void afterDoTag(TabTag tag) throws IOException, JspException {
		tag.getWriter().print("\n</div>\n");
	}

	public void printTabHeader(WriterWrapper<?> out, MessagesRepository repository, TabTag tab) throws IOException, JspException {
		String id = tab.getId();
		String label = (String) tab.evaluateExpression(repository.guessString(id));
		UrlBuilder url = tab.getUrl();
		if (url.hasEvent()) {
			url.getEvent().decorate(tab);
		}

		out.print("<li><a");
		out.printAttribute("class", tab.getCssBuilder().getCss());
		out.printAttribute("target", tab.getTarget());
		out.printAttribute("href", url.getURL());
		out.printAttribute("method", tab.getMethod());
		out.print(">").print(label).print("</a></li>\n");
	}

	/**
	 * Calculate the URL to put on a tab header
	private String getHeaderURL(String id) {
		return "#" + id;
	}
	 */

}
