/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.validator;

import org.apache.commons.lang.StringUtils;
import org.loom.i18n.Message;
import org.loom.servlet.names.HtmlExtendedAttributeNames;
import org.loom.tags.FormInputTag;
import org.loom.util.PropertyUtils;


public abstract class AbstractPropertyValidator implements PropertyValidator {
	
	/** the message key to be used, null for default */
	private String overridenMessageKey;
	
	/** the property path of the validated field */
    private String propertyPath;

    private boolean validateCollectionContainer;
    
    /** the prefix of the javascript message property, e.g.: "string" for string-message="error.emailFailed" */
    private String messagePrefix;
    
    /** true if the any error message should be bound to this field, false to use unbound {@link Message}s */
    boolean bindMessages = true;
    
    public AbstractPropertyValidator() {
    	// reasonable default
		this.messagePrefix = StringUtils.substringBeforeLast(getClass().getSimpleName(), "Validator").toLowerCase();
	}

    /**
     * Add attributes to the tag based on this Validator instance metadata
     * @param tag the tag to be modified
     */
	public void decorate(FormInputTag tag) {
		if (overridenMessageKey != null) {
			tag.setExtendedAttribute(messagePrefix + "-" + HtmlExtendedAttributeNames.MESSAGE, overridenMessageKey);
		}
	}
	
	/**
	 * Adds my on and except conditions to the provided event filter 
	 * @param filter
	 * /
	public void addEventFilter(PathMatcher filter) {
		this.eventFilter = new PathMatcher(filter, on, except);
	}*/

	/**
	 * Adds a property node to the beginning of this property path
	 */
	public void pushPropertyPath(String prefix) {
		propertyPath = PropertyUtils.concatPropertyPath(prefix, propertyPath);
	}

	public String getPropertyPath() {
		return propertyPath;
	}

	public void setPropertyPath(String propertyPath) {
		this.propertyPath = propertyPath;
	}
 
	/**
	 * @return true if this validation must be applied to containers (lists, maps, arrays) instead of its contents.
	 * If false, the validation will be applied to each content,if true it will be applied to the container.
	 * Defaults false
	 */
	public boolean validateCollectionContainer() {
		return validateCollectionContainer;
	}

	public String getOverridenMessageKey() {
		return overridenMessageKey;
	}

	public void setOverridenMessageKey(String message) {
		this.overridenMessageKey = message;
	}

	protected String getMessagePrefix() {
		return messagePrefix;
	}

	protected void setMessagePrefix(String messagePrefix) {
		this.messagePrefix = messagePrefix;
	}

	protected boolean isValidateCollectionContainer() {
		return validateCollectionContainer;
	}

	protected void setValidateCollectionContainer(
			boolean validateCollectionContainer) {
		this.validateCollectionContainer = validateCollectionContainer;
	}

	public boolean isBindMessages() {
		return bindMessages;
	}

	public void setBindMessages(boolean bindMessages) {
		this.bindMessages = bindMessages;
	}

}
