/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.validator;

import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.util.AntPathMatcher;

/**
 * Returns true if the event matches ANY of the configured includes[]
 * events and NONE of the excludes[]
 * 
 * @author icoloma
 */
public class PathMatcherRule {

	/** events included, may contain wildcards */
	private String[] includes;
	
	/** events excluded, may contain wildcards */
	private String[] excludes;
	
	/** class used to resolve wildcards comparison */
	private AntPathMatcher matcher = new AntPathMatcher();
	
	public PathMatcherRule(String[] includes, String[] excludes) {
		this.includes = includes;
		this.excludes = excludes;
	}

	public boolean matches(String event) {
		if (excludes != null)
			for (String exclude : excludes) 
				if (matcher.match(exclude, event))
					return false;
		if (includes == null || includes.length == 0) {
			return true;
		}
		for (String include : includes) 
			if (matcher.match(include, event))
				return true;
		return false;
	}

	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder(); 
		builder.append("Rule { ");
		if (!ArrayUtils.isEmpty(includes))
			builder.append("includes = [").append(StringUtils.join(includes, ", ")).append("]");
		if (!ArrayUtils.isEmpty(excludes))
			builder.append(", excludes = [").append(StringUtils.join(excludes, ", ")).append("]");
		builder.append("}");
		return builder.toString();
	}
}
