/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.validator;

import java.util.Collection;
import java.util.Map;

/**
 * Creates the appropiate RequiredValidatorclass, depending on the property type
 * @author Ignacio Coloma
 */
public class RequiredValidatorFactory {

	/**
	 * Create a RequiredValidator instance for the specified property class
	 * @param propertyClass the property class
	 * @return the instance of RequiredValidator
	 */
	public static AbstractRequiredValidator<?> createValidator(Class<?> propertyClass) {
		if (String.class.equals(propertyClass)) {
			return new RequiredStringValidator();
		} else if (Collection.class.isAssignableFrom(propertyClass)) {
			return new RequiredCollectionValidator();
		} else if (Map.class.isAssignableFrom(propertyClass)) {
			return new RequiredMapValidator();
		} else if (propertyClass.isArray()) {
			return new RequiredArrayValidator();
		} else {
			return new RequiredObjectValidator();
		}
	}
}
